import React from "react";
import Container from "../Container";
import SelectInput from "../form/SelectInput";
import SingleProduct from "../ProductDetails/SingleProduct";
import useLanguage from "../../hooks/useLanguage";
function SellerAbout({ data }) {
  const language = useLanguage();
  return (
    <section className="lg:pt-20 pt-14 bg-[#FDF9FF]">
      <Container>
        <div className="grid lg:grid-cols-12 lg:gap-7 gap-4 ">
          <div className="lg:col-span-8 ">
            <div className="bg-dark-300 lg:p-[30px] p-2  rounded-lg w-full flex flex-col xl:flex-row  lg:items-center gap-7 h-fit justify-center ">
              <div className="xl:w-1/3 w-full">
                <div className="bg-white border border-primary-100 rounded-lg p-4">
                  <div className="w-full flex justify-center items-center h-[167px] bg-primary-200 bg-opacity-10">
                    <img
                      src={process.env.BASE_URL + data.seller.logo}
                      className=" max-h-32"
                      alt=""
                    />
                  </div>
                  <div className="py-5">
                    <h4 className="text-2xl font-bold mb-4">
                      {data.seller.shop_name}
                    </h4>
                    <a
                      href="mailto:+33 (535) 32423"
                      className="flex gap-2 items-center text-dark-300 mb-3"
                    >
                      <svg
                        xmlns="http://www.w3.org/2000/svg"
                        width="24"
                        height="25"
                        viewBox="0 0 24 25"
                        fill="none"
                      >
                        <path
                          d="M6 8.28882L9.7812 10.8096C11.1248 11.7054 12.8752 11.7053 14.2188 10.8096L18 8.28882M6 21.2888H18C20.2091 21.2888 22 19.498 22 17.2888V7.28882C22 5.07968 20.2091 3.28882 18 3.28882H6C3.79086 3.28882 2 5.07968 2 7.28882V17.2888C2 19.498 3.79086 21.2888 6 21.2888Z"
                          stroke="#8037A9"
                          strokeWidth="1.5"
                          strokeLinecap="round"
                          strokeLinejoin="round"
                        />
                      </svg>
                      {data.seller.email}
                    </a>
                    <a
                      href="tel:+3353532423"
                      className="flex gap-2 items-center"
                    >
                      <svg
                        width="24"
                        height="25"
                        viewBox="0 0 24 25"
                        fill="none"
                        xmlns="http://www.w3.org/2000/svg"
                      >
                        <path
                          d="M21 19.2888V17.6429C21 16.8251 20.5021 16.0897 19.7428 15.7859L17.7086 14.9723C16.7429 14.586 15.6422 15.0044 15.177 15.9348L15 16.2888C15 16.2888 12.5 15.7888 10.5 13.7888C8.5 11.7888 8 9.28882 8 9.28882L8.35402 9.11181C9.28438 8.64663 9.70285 7.54596 9.31654 6.58017L8.50289 4.54604C8.19916 3.78672 7.46374 3.28882 6.64593 3.28882H5C3.89543 3.28882 3 4.18425 3 5.28882C3 14.1254 10.1634 21.2888 19 21.2888C20.1046 21.2888 21 20.3934 21 19.2888Z"
                          stroke="#8037A9"
                          strokeWidth="1.5"
                          strokeLinejoin="round"
                        />
                      </svg>
                      {data.seller.phone}
                    </a>
                    <span className="bg-primary-100 text-primary-200 p-2 rounded block mt-4 notranslate">
                      {data.totalProducts}{" "}
                      {language["Supplier Product Available"]}
                    </span>
                  </div>
                </div>
              </div>
              <div className="xl:w-2/3">
                <div className="">
                  <h2 className="text-3xl lg:text-4xl font-bold text-white mb-5 notranslate">
                    {language["About"]}{" "}
                  </h2>
                  <p className="text-white text-base">{data.aboutText.about}</p>
                  {/* <p className="text-white text-base py-5">
                    There are many variations of passages of Lorem Ipsum
                    available, but the majority have suffered alteration in some
                    form, by injected humor, supper.
                  </p>
                  <p className="text-white text-base">
                    There are many variations of passages of Lorem Ipsum
                    available, but the to let majority have suffered alteration
                    in some form, by injected humor passages randomized words
                    which don&apos;t look even slightly believable.
                  </p> */}
                </div>
              </div>
            </div>
            <div className="flex flex-col w-full mt-11 gap-5">
              <div className="flex gap-4 flex-col md:flex-row w-full justify-between">
                {/* <SelectInput options={data.categories} /> */}
                {/* <div className="flex sm:gap-4 gap-1  ">
                  <SelectInput
                    options={[
                      { name: "Cheap Open First" },
                      { name: "option-2" },
                      { name: "option-3" },
                    ]}
                  />
                  <SelectInput
                    options={[
                      { name: "Ton" },
                      { name: "option-2" },
                      { name: "option-3" },
                    ]}
                  />
                </div> */}
              </div>
              {data?.products?.map((product) => (
                <SingleProduct
                  key={product.id}
                  product={product}
                  activeWarehouse={false}
                />
              ))}
            </div>
          </div>

          <div className="lg:col-span-4 space-y-7">
            <div className="bg-white rounded p-6">
              <h3 className="text-2xl font-bold text-dark-300 mb-5 notranslate">
                {language["Supplier Details"]}
              </h3>
              <a
                target="blank"
                href={data.downlodpdfLink}
                className="flex relative animated-btn gap-2.5 text-sm text-dark-300 items-center px-5 py-3.5 rounded bg-secondary notranslate"
              >
                <svg
                  width="16"
                  height="16"
                  viewBox="0 0 16 16"
                  fill="none"
                  xmlns="http://www.w3.org/2000/svg"
                >
                  <path
                    d="M5.90054 11.8C7.0721 12.9716 8.9716 12.9716 10.1432 11.8L10.1432 11.8L12.2846 9.65866C12.6818 9.27497 12.6928 8.64191 12.3091 8.24466C11.9254 7.84741 11.2924 7.83641 10.8951 8.22009C10.8868 8.22812 10.8786 8.23634 10.8706 8.24466L9.01523 10.0993L8.99988 1C8.99988 0.447719 8.55216 0 7.99988 0C7.4476 0 6.99988 0.447719 6.99988 1L7.01388 10.0847L5.17323 8.244C4.77598 7.86031 4.14291 7.87131 3.75923 8.26856C3.38495 8.65609 3.38495 9.27047 3.75923 9.658L5.90054 11.8Z"
                    fill="#001C31"
                  />
                  <path
                    d="M15 9.66675C14.4477 9.66675 14 10.1145 14 10.6667V13.7274C13.9996 13.8778 13.8778 13.9997 13.7273 14.0001H2.27266C2.12222 13.9997 2.00034 13.8778 2 13.7274V10.6667C2 10.1145 1.55228 9.66675 1 9.66675C0.447719 9.66675 0 10.1145 0 10.6667V13.7274C0.00146875 14.982 1.01812 15.9986 2.27266 16.0001H13.7273C14.9819 15.9986 15.9985 14.982 16 13.7274V10.6668C16 10.1145 15.5523 9.66675 15 9.66675Z"
                    fill="#001C31"
                  />
                </svg>
                {language["Download Supplier Card"]}
              </a>
            </div>
            <div className="bg-white px-6 py-7 rounded">
              <h3 className="text-2xl font-bold text-dark-300 notranslate">
                {language["Warehouse Details"]}
              </h3>
              <div className="divide-y max-w-[100vw] overflow-hidden divide-primary-100">
                {data.warehouse.map((info) => (
                  <div key={info.id} className="space-y-3 py-5">
                    <p className="text-lg font-medium mb-2 text-dark-300">
                      {info.name}
                    </p>
                    <div>
                      <p className="text-sm font-medium text-dark-300 notranslate">
                        {language["Location"]}
                      </p>
                      <address className="text-sm leading-6 text-dark-200 not-italic">
                        <span>:</span>
                        {info.location}
                      </address>
                    </div>
                    <div>
                      <p className=" text-sm font-medium text-dark-300 notranslate">
                        {language["Contacts"]}:
                        <span className="text-sm font-normal leading-6 text-dark-200">
                          {info.contact}
                        </span>
                      </p>
                    </div>
                    <div>
                      <p className="text-sm font-medium text-dark-300 notranslate">
                        {language["Opening Time"]}:{" "}
                        <span className="text-primary-200 font-normal">
                          {info.opening_time}
                        </span>
                      </p>
                    </div>
                  </div>
                ))}
              </div>
            </div>
          </div>
        </div>
      </Container>
    </section>
  );
}

export default SellerAbout;
